[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] xsm: rename security_pirq_sid to security_irq_sid



# HG changeset patch
# User Daniel De Graaf <dgdegra@xxxxxxxxxxxxx>
# Date 1322862470 28800
# Node ID 346da8c033f6af083439cda268db8c23136297e5
# Parent  e95157d4c7a2676ead5623cb1ce275b4caa17c31
xsm: rename security_pirq_sid to security_irq_sid

Attempting to manage the PIRQ namespace is not useful as guests can
assign any mapping of IRQ to PIRQ (although the identity mapping is
the most common). Change the internal names to reflect this change.

Signed-off-by: Daniel De Graaf <dgdegra@xxxxxxxxxxxxx>
Committed-by: Keir Fraser <keir@xxxxxxx>
---


diff -r e95157d4c7a2 -r 346da8c033f6 xen/xsm/flask/hooks.c
--- a/xen/xsm/flask/hooks.c     Fri Dec 02 13:47:08 2011 -0800
+++ b/xen/xsm/flask/hooks.c     Fri Dec 02 13:47:50 2011 -0800
@@ -666,7 +666,7 @@
     ssec = current->domain->ssid;
     tsec = d->ssid;
 
-    rc = security_pirq_sid(pirq, &rsid);
+    rc = security_irq_sid(pirq, &rsid);
     if ( rc )
         return rc;
 
@@ -1151,7 +1151,7 @@
 
     irq = domain_pirq_to_irq(d, bind->machine_irq);
 
-    rc = security_pirq_sid(irq, &rsid);
+    rc = security_irq_sid(irq, &rsid);
     if ( rc )
         return rc;
 
diff -r e95157d4c7a2 -r 346da8c033f6 xen/xsm/flask/include/security.h
--- a/xen/xsm/flask/include/security.h  Fri Dec 02 13:47:08 2011 -0800
+++ b/xen/xsm/flask/include/security.h  Fri Dec 02 13:47:50 2011 -0800
@@ -71,7 +71,7 @@
 
 int security_get_user_sids(u32 callsid, char *username, u32 **sids, u32 *nel);
 
-int security_pirq_sid(int pirq, u32 *out_sid);
+int security_irq_sid(int pirq, u32 *out_sid);
 
 int security_iomem_sid(unsigned long, u32 *out_sid);
 
diff -r e95157d4c7a2 -r 346da8c033f6 xen/xsm/flask/ss/services.c
--- a/xen/xsm/flask/ss/services.c       Fri Dec 02 13:47:08 2011 -0800
+++ b/xen/xsm/flask/ss/services.c       Fri Dec 02 13:47:50 2011 -0800
@@ -1514,11 +1514,11 @@
 }
 
 /**
  * security_pirq_sid - Obtain the SID for a physical irq.
  * @pirq: physical irq
  * @out_sid: security identifier
  */
-int security_pirq_sid(int pirq, u32 *out_sid)
+int security_irq_sid(int pirq, u32 *out_sid)
 {
     int rc = 0;
     struct ocontext *c;
@@ -1514,11 +1514,11 @@
 
 /**
- * security_pirq_sid - Obtain the SID for a physical irq.
+ * security_irq_sid - Obtain the SID for a physical irq.
  * @pirq: physical irq
  * @out_sid: security identifier

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.